@@ -1,18 +1,30 @@
 #!/usr/bin/env bash
+
 # set -o xtrace   # Write all commands first to stderr
 set -o errexit  # Exit the script with error if any of the commands fail
 
 echo "Setting up environment"
-export NPM_OPTIONS="${NPM_OPTIONS}"
-. ./.evergreen/setup_environment.sh
+
+export PATH="/opt/mongodbtoolchain/v2/bin:$PATH"
+hash -r
+
+export NODE_LTS_NAME="gallium"
+source ./.evergreen/install-dependencies.sh
+
+
 
 # Handle the circular dependency when testing with a real client.
-export MONGODB_CLIENT_ENCRYPTION_OVERRIDE="$(pwd)"
+MONGODB_CLIENT_ENCRYPTION_OVERRIDE="$(pwd)"
+export MONGODB_CLIENT_ENCRYPTION_OVERRIDE
 
 # install node dependencies
 echo "Installing package dependencies (includes a static build)"
 bash ./etc/build-static.sh
-# npm install
+
+if [[ $OMIT_PEER_DEPS != "true" ]]; then
+    npm install '@aws-sdk/credential-providers'
+    npm install 'gcp-metadata'
+fi
 
 # Run tests
 echo "Running tests"
