@@ -13,10 +13,7 @@ const stateMachine = require('../lib/stateMachine')({ mongodb });
 const StateMachine = stateMachine.StateMachine;
 const MongocryptdManager = require('../lib/mongocryptdManager').MongocryptdManager;
 
-const chai = require('chai');
-const expect = chai.expect;
-chai.use(require('chai-subset'));
-chai.use(require('sinon-chai'));
+const { expect } = require('chai');
 
 const sharedLibrarySuffix =
   process.platform === 'win32' ? 'dll' : process.platform === 'darwin' ? 'dylib' : 'so';
@@ -103,7 +100,7 @@ describe('AutoEncrypter', function () {
       });
 
     sandbox.stub(StateMachine.prototype, 'fetchKeys').callsFake((client, ns, filter, callback) => {
-      // mock data is already seriaized, our action deals with the result of a cursor
+      // mock data is already serialized, our action deals with the result of a cursor
       const deserializedKey = BSON.deserialize(MOCK_KEYDOCUMENT_RESPONSE);
       callback(null, [deserializedKey]);
     });
@@ -371,7 +368,7 @@ describe('AutoEncrypter', function () {
       const secretKey = 'example';
 
       before(function () {
-        if (process.env.NPM_OPTIONS === '--no-optional') {
+        if (!requirements.credentialProvidersInstalled.aws) {
           this.currentTest.skipReason = 'Cannot refresh credentials without sdk provider';
           this.currentTest.skip();
           return;
@@ -410,7 +407,7 @@ describe('AutoEncrypter', function () {
       const secretKey = 'example';
 
       before(function () {
-        if (!process.env.NPM_OPTIONS) {
+        if (requirements.credentialProvidersInstalled.aws) {
           this.currentTest.skipReason = 'With optional sdk installed credentials would be loaded.';
           this.currentTest.skip();
           return;
