@@ -15,6 +15,24 @@ const SKIP_LIVE_TESTS = !!process.env.MONGODB_NODE_SKIP_LIVE_TESTS;
 const SKIP_AWS_TESTS =
   SKIP_LIVE_TESTS || !AWS_ACCESS_KEY_ID || !AWS_SECRET_ACCESS_KEY || !AWS_REGION || !AWS_CMK_ID;
 
+function isAWSCredentialProviderInstalled() {
+  try {
+    require.resolve('@aws-sdk/credential-providers');
+    return true;
+  } catch {
+    return false;
+  }
+}
+
+function isGCPCredentialProviderInstalled() {
+  try {
+    require.resolve('gcp-metadata');
+    return true;
+  } catch {
+    return false;
+  }
+}
+
 module.exports = {
   SKIP_LIVE_TESTS,
   SKIP_AWS_TESTS,
@@ -25,5 +43,9 @@ module.exports = {
     AWS_CMK_ID
   },
   awsKmsProviders,
-  awsDataKeyOptions
+  awsDataKeyOptions,
+  credentialProvidersInstalled: {
+    aws: isAWSCredentialProviderInstalled(),
+    gcp: isGCPCredentialProviderInstalled()
+  }
 };
