@@ -3,6 +3,9 @@ import sys
 
 from setuptools import setup, find_packages
 
+if sys.version_info[:3] < (3, 7):
+    raise RuntimeError("pymongocrypt requires Python version >= 3.7")
+
 # Make our Windows and macOS wheels platform specific because we embed
 # libmongocrypt. On Linux we ship manylinux2010 wheels which cannot do this or
 # else auditwheel raises the following error:
@@ -22,8 +25,8 @@ if sys.platform in ('win32', 'darwin'):
 
             def get_tag(self):
                 python, abi, plat = _bdist_wheel.get_tag(self)
-                # Our python source is py2/3 compatible.
-                python, abi = 'py2.py3', 'none'
+                # Our python source is py3 compatible.
+                python, abi = 'py3', 'none'
                 return python, abi, plat
 
         cmdclass['bdist_wheel'] = bdist_wheel
@@ -50,7 +53,13 @@ setup(
     package_data={'pymongocrypt': ['*.dll', '*.so', '*.dylib']},
     zip_safe=False,
     # Note cryptography is uncapped because it does not follow semver.
-    install_requires=["cffi>=1.12.0,<2", "cryptography>=2.0", "requests<3.0.0"],
+    install_requires=[
+        "cffi>=1.12.0,<2",
+        "cryptography>=2.0",
+        # cryptography 40 dropped support for PyPy <7.3.10.
+        "cryptography<40;platform_python_implementation=='PyPy' and implementation_version<'7.3.10'",
+        "requests<3.0.0"
+    ],
     author="Shane Harvey",
     author_email="mongodb-user@googlegroups.com",
     url="https://github.com/mongodb/libmongocrypt/tree/master/bindings/python",
@@ -58,7 +67,7 @@ setup(
               "bson"],
     test_suite="test",
     license="Apache License, Version 2.0",
-    python_requires=">=2.7,!=3.0.*,!=3.1.*,!=3.2.*,!=3.3.*",
+    python_requires=">=3.7",
     classifiers=[
         "Development Status :: 5 - Production/Stable",
         "Intended Audience :: Developers",
@@ -66,12 +75,8 @@ setup(
         "Operating System :: MacOS :: MacOS X",
         "Operating System :: Microsoft :: Windows",
         "Operating System :: POSIX",
-        "Programming Language :: Python :: 2",
-        "Programming Language :: Python :: 2.7",
         "Programming Language :: Python :: 3",
-        "Programming Language :: Python :: 3.4",
-        "Programming Language :: Python :: 3.5",
-        "Programming Language :: Python :: 3.6",
+        "Programming Language :: Python :: 3 :: Only",
         "Programming Language :: Python :: 3.7",
         "Programming Language :: Python :: 3.8",
         "Programming Language :: Python :: 3.9",
