@@ -23,8 +23,8 @@
  * See all public API documentation in: @ref mongocrypt.h
  */
 
-#include "mongocrypt-export.h"
 #include "mongocrypt-compat.h"
+#include "mongocrypt-export.h"
 
 /* clang-format off */
 #ifndef __has_include
@@ -46,9 +46,7 @@
  * @returns a NULL terminated version string for libmongocrypt.
  */
 MONGOCRYPT_EXPORT
-const char *
-mongocrypt_version (uint32_t *len);
-
+const char *mongocrypt_version(uint32_t *len);
 
 /**
  * A non-owning view of a byte buffer.
@@ -74,7 +72,6 @@ mongocrypt_version (uint32_t *len);
  */
 typedef struct _mongocrypt_binary_t mongocrypt_binary_t;
 
-
 /**
  * Create a new non-owning view of a buffer (data + length).
  *
@@ -83,9 +80,7 @@ typedef struct _mongocrypt_binary_t mongocrypt_binary_t;
  * @returns A new mongocrypt_binary_t.
  */
 MONGOCRYPT_EXPORT
-mongocrypt_binary_t *
-mongocrypt_binary_new (void);
-
+mongocrypt_binary_t *mongocrypt_binary_new(void);
 
 /**
  * Create a new non-owning view of a buffer (data + length).
@@ -97,9 +92,7 @@ mongocrypt_binary_new (void);
  * @returns A new @ref mongocrypt_binary_t.
  */
 MONGOCRYPT_EXPORT
-mongocrypt_binary_t *
-mongocrypt_binary_new_from_data (uint8_t *data, uint32_t len);
-
+mongocrypt_binary_t *mongocrypt_binary_new_from_data(uint8_t *data, uint32_t len);
 
 /**
  * Get a pointer to the viewed data.
@@ -109,9 +102,7 @@ mongocrypt_binary_new_from_data (uint8_t *data, uint32_t len);
  * @returns A pointer to the viewed data.
  */
 MONGOCRYPT_EXPORT
-uint8_t *
-mongocrypt_binary_data (const mongocrypt_binary_t *binary);
-
+uint8_t *mongocrypt_binary_data(const mongocrypt_binary_t *binary);
 
 /**
  * Get the length of the viewed data.
@@ -121,9 +112,7 @@ mongocrypt_binary_data (const mongocrypt_binary_t *binary);
  * @returns The length of the viewed data.
  */
 MONGOCRYPT_EXPORT
-uint32_t
-mongocrypt_binary_len (const mongocrypt_binary_t *binary);
-
+uint32_t mongocrypt_binary_len(const mongocrypt_binary_t *binary);
 
 /**
  * Free the @ref mongocrypt_binary_t.
@@ -133,9 +122,7 @@ mongocrypt_binary_len (const mongocrypt_binary_t *binary);
  * @param[in] binary The mongocrypt_binary_t destroy.
  */
 MONGOCRYPT_EXPORT
-void
-mongocrypt_binary_destroy (mongocrypt_binary_t *binary);
-
+void mongocrypt_binary_destroy(mongocrypt_binary_t *binary);
 
 /**
  * Indicates success or contains error information.
@@ -151,13 +138,12 @@ typedef struct _mongocrypt_status_t mongocrypt_status_t;
  * Indicates the type of error.
  */
 typedef enum {
-   MONGOCRYPT_STATUS_OK = 0,
-   MONGOCRYPT_STATUS_ERROR_CLIENT = 1,
-   MONGOCRYPT_STATUS_ERROR_KMS = 2,
-   MONGOCRYPT_STATUS_ERROR_CRYPT_SHARED = 3,
+    MONGOCRYPT_STATUS_OK = 0,
+    MONGOCRYPT_STATUS_ERROR_CLIENT = 1,
+    MONGOCRYPT_STATUS_ERROR_KMS = 2,
+    MONGOCRYPT_STATUS_ERROR_CRYPT_SHARED = 3,
 } mongocrypt_status_type_t;
 
-
 /**
  * Create a new status object.
  *
@@ -168,9 +154,7 @@ typedef enum {
  * @returns A new status object.
  */
 MONGOCRYPT_EXPORT
-mongocrypt_status_t *
-mongocrypt_status_new (void);
-
+mongocrypt_status_t *mongocrypt_status_new(void);
 
 /**
  * Set a status object with message, type, and code.
@@ -189,13 +173,11 @@ mongocrypt_status_new (void);
  *
  */
 MONGOCRYPT_EXPORT
-void
-mongocrypt_status_set (mongocrypt_status_t *status,
-                       mongocrypt_status_type_t type,
-                       uint32_t code,
-                       const char *message,
-                       int32_t message_len);
-
+void mongocrypt_status_set(mongocrypt_status_t *status,
+                           mongocrypt_status_type_t type,
+                           uint32_t code,
+                           const char *message,
+                           int32_t message_len);
 
 /**
  * Indicates success or the type of error.
@@ -205,9 +187,7 @@ mongocrypt_status_set (mongocrypt_status_t *status,
  * @returns A @ref mongocrypt_status_type_t.
  */
 MONGOCRYPT_EXPORT
-mongocrypt_status_type_t
-mongocrypt_status_type (mongocrypt_status_t *status);
-
+mongocrypt_status_type_t mongocrypt_status_type(mongocrypt_status_t *status);
 
 /**
  * Get an error code or 0.
@@ -217,9 +197,7 @@ mongocrypt_status_type (mongocrypt_status_t *status);
  * @returns An error code.
  */
 MONGOCRYPT_EXPORT
-uint32_t
-mongocrypt_status_code (mongocrypt_status_t *status);
-
+uint32_t mongocrypt_status_code(mongocrypt_status_t *status);
 
 /**
  * Get the error message associated with a status or NULL.
@@ -231,9 +209,7 @@ mongocrypt_status_code (mongocrypt_status_t *status);
  * @returns A NULL terminated error message or NULL.
  */
 MONGOCRYPT_EXPORT
-const char *
-mongocrypt_status_message (mongocrypt_status_t *status, uint32_t *len);
-
+const char *mongocrypt_status_message(mongocrypt_status_t *status, uint32_t *len);
 
 /**
  * Returns true if the status indicates success.
@@ -244,9 +220,7 @@ mongocrypt_status_message (mongocrypt_status_t *status, uint32_t *len);
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_status_ok (mongocrypt_status_t *status);
-
+bool mongocrypt_status_ok(mongocrypt_status_t *status);
 
 /**
  * Free the memory for a status object.
@@ -254,21 +228,19 @@ mongocrypt_status_ok (mongocrypt_status_t *status);
  * @param[in] status The status to destroy.
  */
 MONGOCRYPT_EXPORT
-void
-mongocrypt_status_destroy (mongocrypt_status_t *status);
+void mongocrypt_status_destroy(mongocrypt_status_t *status);
 
 /**
  * Indicates the type of log message.
  */
 typedef enum {
-   MONGOCRYPT_LOG_LEVEL_FATAL = 0,
-   MONGOCRYPT_LOG_LEVEL_ERROR = 1,
-   MONGOCRYPT_LOG_LEVEL_WARNING = 2,
-   MONGOCRYPT_LOG_LEVEL_INFO = 3,
-   MONGOCRYPT_LOG_LEVEL_TRACE = 4
+    MONGOCRYPT_LOG_LEVEL_FATAL = 0,
+    MONGOCRYPT_LOG_LEVEL_ERROR = 1,
+    MONGOCRYPT_LOG_LEVEL_WARNING = 2,
+    MONGOCRYPT_LOG_LEVEL_INFO = 3,
+    MONGOCRYPT_LOG_LEVEL_TRACE = 4
 } mongocrypt_log_level_t;
 
-
 /**
  * A log callback function. Set a custom log callback with @ref
  * mongocrypt_setopt_log_handler.
@@ -278,11 +250,7 @@ typedef enum {
  * @param[in] ctx A context provided by the caller of @ref
  * mongocrypt_setopt_log_handler.
  */
-typedef void (*mongocrypt_log_fn_t) (mongocrypt_log_level_t level,
-                                     const char *message,
-                                     uint32_t message_len,
-                                     void *ctx);
-
+typedef void (*mongocrypt_log_fn_t)(mongocrypt_log_level_t level, const char *message, uint32_t message_len, void *ctx);
 
 /**
  * The top-level handle to libmongocrypt.
@@ -298,7 +266,6 @@ typedef void (*mongocrypt_log_fn_t) (mongocrypt_log_level_t level,
  */
 typedef struct _mongocrypt_t mongocrypt_t;
 
-
 /**
  * Allocate a new @ref mongocrypt_t object.
  *
@@ -309,9 +276,7 @@ typedef struct _mongocrypt_t mongocrypt_t;
  * @returns A new @ref mongocrypt_t object.
  */
 MONGOCRYPT_EXPORT
-mongocrypt_t *
-mongocrypt_new (void);
-
+mongocrypt_t *mongocrypt_new(void);
 
 /**
  * Set a handler on the @ref mongocrypt_t object to get called on every log
@@ -326,11 +291,7 @@ mongocrypt_new (void);
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_setopt_log_handler (mongocrypt_t *crypt,
-                               mongocrypt_log_fn_t log_fn,
-                               void *log_ctx);
-
+bool mongocrypt_setopt_log_handler(mongocrypt_t *crypt, mongocrypt_log_fn_t log_fn, void *log_ctx);
 
 /**
  * Configure an AWS KMS provider on the @ref mongocrypt_t object.
@@ -354,13 +315,11 @@ mongocrypt_setopt_log_handler (mongocrypt_t *crypt,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_setopt_kms_provider_aws (mongocrypt_t *crypt,
-                                    const char *aws_access_key_id,
-                                    int32_t aws_access_key_id_len,
-                                    const char *aws_secret_access_key,
-                                    int32_t aws_secret_access_key_len);
-
+bool mongocrypt_setopt_kms_provider_aws(mongocrypt_t *crypt,
+                                        const char *aws_access_key_id,
+                                        int32_t aws_access_key_id_len,
+                                        const char *aws_secret_access_key,
+                                        int32_t aws_secret_access_key_len);
 
 /**
  * Configure a local KMS provider on the @ref mongocrypt_t object.
@@ -377,9 +336,7 @@ mongocrypt_setopt_kms_provider_aws (mongocrypt_t *crypt,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_setopt_kms_provider_local (mongocrypt_t *crypt,
-                                      mongocrypt_binary_t *key);
+bool mongocrypt_setopt_kms_provider_local(mongocrypt_t *crypt, mongocrypt_binary_t *key);
 
 /**
  * Configure KMS providers with a BSON document.
@@ -393,9 +350,7 @@ mongocrypt_setopt_kms_provider_local (mongocrypt_t *crypt,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_setopt_kms_providers (mongocrypt_t *crypt,
-                                 mongocrypt_binary_t *kms_providers);
+bool mongocrypt_setopt_kms_providers(mongocrypt_t *crypt, mongocrypt_binary_t *kms_providers);
 
 /**
  * Set a local schema map for encryption.
@@ -410,9 +365,7 @@ mongocrypt_setopt_kms_providers (mongocrypt_t *crypt,
  * Retrieve it with @ref mongocrypt_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_setopt_schema_map (mongocrypt_t *crypt,
-                              mongocrypt_binary_t *schema_map);
+bool mongocrypt_setopt_schema_map(mongocrypt_t *crypt, mongocrypt_binary_t *schema_map);
 
 /**
  * Set a local EncryptedFieldConfigMap for encryption.
@@ -427,10 +380,7 @@ mongocrypt_setopt_schema_map (mongocrypt_t *crypt,
  * Retrieve it with @ref mongocrypt_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_setopt_encrypted_field_config_map (mongocrypt_t *crypt,
-                                              mongocrypt_binary_t *efc_map);
-
+bool mongocrypt_setopt_encrypted_field_config_map(mongocrypt_t *crypt, mongocrypt_binary_t *efc_map);
 
 /**
  * @brief Append an additional search directory to the search path for loading
@@ -461,10 +411,7 @@ mongocrypt_setopt_encrypted_field_config_map (mongocrypt_t *crypt,
  * appended here will have no effect.
  */
 MONGOCRYPT_EXPORT
-void
-mongocrypt_setopt_append_crypt_shared_lib_search_path (mongocrypt_t *crypt,
-                                                       const char *path);
-
+void mongocrypt_setopt_append_crypt_shared_lib_search_path(mongocrypt_t *crypt, const char *path);
 
 /**
  * @brief Set a single override path for loading the crypt_shared dynamic
@@ -490,10 +437,7 @@ mongocrypt_setopt_append_crypt_shared_lib_search_path (mongocrypt_t *crypt,
  * the initialization of mongocrypt_t will fail with an error.
  */
 MONGOCRYPT_EXPORT
-void
-mongocrypt_setopt_set_crypt_shared_lib_path_override (mongocrypt_t *crypt,
-                                                      const char *path);
-
+void mongocrypt_setopt_set_crypt_shared_lib_path_override(mongocrypt_t *crypt, const char *path);
 
 /**
  * @brief Opt-into handling the MONGOCRYPT_CTX_NEED_KMS_CREDENTIALS state.
@@ -510,9 +454,7 @@ mongocrypt_setopt_set_crypt_shared_lib_path_override (mongocrypt_t *crypt,
  * @param[in] crypt The @ref mongocrypt_t object to update
  */
 MONGOCRYPT_EXPORT
-void
-mongocrypt_setopt_use_need_kms_credentials_state (mongocrypt_t *crypt);
-
+void mongocrypt_setopt_use_need_kms_credentials_state(mongocrypt_t *crypt);
 
 /**
  * Initialize new @ref mongocrypt_t object.
@@ -528,9 +470,7 @@ mongocrypt_setopt_use_need_kms_credentials_state (mongocrypt_t *crypt);
  * options are invalid.
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_init (mongocrypt_t *crypt);
-
+bool mongocrypt_init(mongocrypt_t *crypt);
 
 /**
  * Get the status associated with a @ref mongocrypt_t object.
@@ -542,9 +482,7 @@ mongocrypt_init (mongocrypt_t *crypt);
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_status (mongocrypt_t *crypt, mongocrypt_status_t *status);
-
+bool mongocrypt_status(mongocrypt_t *crypt, mongocrypt_status_t *status);
 
 /**
  * Destroy the @ref mongocrypt_t object.
@@ -552,8 +490,7 @@ mongocrypt_status (mongocrypt_t *crypt, mongocrypt_status_t *status);
  * @param[in] crypt The @ref mongocrypt_t object to destroy.
  */
 MONGOCRYPT_EXPORT
-void
-mongocrypt_destroy (mongocrypt_t *crypt);
+void mongocrypt_destroy(mongocrypt_t *crypt);
 
 /**
  * Obtain a nul-terminated version string of the loaded crypt_shared dynamic
@@ -574,10 +511,7 @@ mongocrypt_destroy (mongocrypt_t *crypt);
  * @ref mongocrypt_crypt_shared_lib_version.
  */
 MONGOCRYPT_EXPORT
-const char *
-mongocrypt_crypt_shared_lib_version_string (const mongocrypt_t *crypt,
-                                            uint32_t *len);
-
+const char *mongocrypt_crypt_shared_lib_version_string(const mongocrypt_t *crypt, uint32_t *len);
 
 /**
  * @brief Obtain a 64-bit constant encoding the version of the loaded
@@ -599,16 +533,13 @@ mongocrypt_crypt_shared_lib_version_string (const mongocrypt_t *crypt,
  * For example, version 6.2.1 would be encoded as: 0x0006'0002'0001'0000
  */
 MONGOCRYPT_EXPORT
-uint64_t
-mongocrypt_crypt_shared_lib_version (const mongocrypt_t *crypt);
-
+uint64_t mongocrypt_crypt_shared_lib_version(const mongocrypt_t *crypt);
 
 /**
  * Manages the state machine for encryption or decryption.
  */
 typedef struct _mongocrypt_ctx_t mongocrypt_ctx_t;
 
-
 /**
  * Create a new uninitialized @ref mongocrypt_ctx_t.
  *
@@ -619,9 +550,7 @@ typedef struct _mongocrypt_ctx_t mongocrypt_ctx_t;
  * @returns A new context.
  */
 MONGOCRYPT_EXPORT
-mongocrypt_ctx_t *
-mongocrypt_ctx_new (mongocrypt_t *crypt);
-
+mongocrypt_ctx_t *mongocrypt_ctx_new(mongocrypt_t *crypt);
 
 /**
  * Get the status associated with a @ref mongocrypt_ctx_t object.
@@ -635,9 +564,7 @@ mongocrypt_ctx_new (mongocrypt_t *crypt);
  * @see mongocrypt_status_ok
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_status (mongocrypt_ctx_t *ctx, mongocrypt_status_t *status);
-
+bool mongocrypt_ctx_status(mongocrypt_ctx_t *ctx, mongocrypt_status_t *status);
 
 /**
  * Set the key id to use for explicit encryption.
@@ -654,9 +581,7 @@ mongocrypt_ctx_status (mongocrypt_ctx_t *ctx, mongocrypt_status_t *status);
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_setopt_key_id (mongocrypt_ctx_t *ctx,
-                              mongocrypt_binary_t *key_id);
+bool mongocrypt_ctx_setopt_key_id(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *key_id);
 
 /**
  * Set the keyAltName to use for explicit encryption or
@@ -681,9 +606,7 @@ mongocrypt_ctx_setopt_key_id (mongocrypt_ctx_t *ctx,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_setopt_key_alt_name (mongocrypt_ctx_t *ctx,
-                                    mongocrypt_binary_t *key_alt_name);
+bool mongocrypt_ctx_setopt_key_alt_name(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *key_alt_name);
 
 /**
  * Set the keyMaterial to use for encrypting data.
@@ -701,9 +624,7 @@ mongocrypt_ctx_setopt_key_alt_name (mongocrypt_ctx_t *ctx,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_setopt_key_material (mongocrypt_ctx_t *ctx,
-                                    mongocrypt_binary_t *key_material);
+bool mongocrypt_ctx_setopt_key_material(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *key_material);
 
 /**
  * Set the algorithm used for encryption to either
@@ -726,14 +647,10 @@ mongocrypt_ctx_setopt_key_material (mongocrypt_ctx_t *ctx,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_setopt_algorithm (mongocrypt_ctx_t *ctx,
-                                 const char *algorithm,
-                                 int len);
+bool mongocrypt_ctx_setopt_algorithm(mongocrypt_ctx_t *ctx, const char *algorithm, int len);
 
 /// String constant for setopt_algorithm "Deterministic" encryption
-#define MONGOCRYPT_ALGORITHM_DETERMINISTIC_STR \
-   "AEAD_AES_256_CBC_HMAC_SHA_512-Deterministic"
+#define MONGOCRYPT_ALGORITHM_DETERMINISTIC_STR "AEAD_AES_256_CBC_HMAC_SHA_512-Deterministic"
 /// String constant for setopt_algorithm "Random" encryption
 #define MONGOCRYPT_ALGORITHM_RANDOM_STR "AEAD_AES_256_CBC_HMAC_SHA_512-Random"
 /// String constant for setopt_algorithm "Indexed" explicit encryption
@@ -745,7 +662,6 @@ mongocrypt_ctx_setopt_algorithm (mongocrypt_ctx_t *ctx,
 /// for public use.
 #define MONGOCRYPT_ALGORITHM_RANGEPREVIEW_STR "RangePreview"
 
-
 /**
  * Identify the AWS KMS master key to use for creating a data key.
  *
@@ -765,13 +681,11 @@ mongocrypt_ctx_setopt_algorithm (mongocrypt_ctx_t *ctx,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_setopt_masterkey_aws (mongocrypt_ctx_t *ctx,
-                                     const char *region,
-                                     int32_t region_len,
-                                     const char *cmk,
-                                     int32_t cmk_len);
-
+bool mongocrypt_ctx_setopt_masterkey_aws(mongocrypt_ctx_t *ctx,
+                                         const char *region,
+                                         int32_t region_len,
+                                         const char *cmk,
+                                         int32_t cmk_len);
 
 /**
  * Identify a custom AWS endpoint when creating a data key.
@@ -791,10 +705,7 @@ mongocrypt_ctx_setopt_masterkey_aws (mongocrypt_ctx_t *ctx,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_setopt_masterkey_aws_endpoint (mongocrypt_ctx_t *ctx,
-                                              const char *endpoint,
-                                              int32_t endpoint_len);
+bool mongocrypt_ctx_setopt_masterkey_aws_endpoint(mongocrypt_ctx_t *ctx, const char *endpoint, int32_t endpoint_len);
 
 /**
  * Set the master key to "local" for creating a data key.
@@ -807,8 +718,7 @@ mongocrypt_ctx_setopt_masterkey_aws_endpoint (mongocrypt_ctx_t *ctx,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_setopt_masterkey_local (mongocrypt_ctx_t *ctx);
+bool mongocrypt_ctx_setopt_masterkey_local(mongocrypt_ctx_t *ctx);
 
 /**
  * Set key encryption key document for creating a data key or for rewrapping
@@ -862,10 +772,7 @@ mongocrypt_ctx_setopt_masterkey_local (mongocrypt_ctx_t *ctx);
  * Retrieve it with @ref mongocrypt_ctx_status.
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_setopt_key_encryption_key (mongocrypt_ctx_t *ctx,
-                                          mongocrypt_binary_t *bin);
-
+bool mongocrypt_ctx_setopt_key_encryption_key(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *bin);
 
 /**
  * Initialize a context to create a data key.
@@ -882,8 +789,7 @@ mongocrypt_ctx_setopt_key_encryption_key (mongocrypt_ctx_t *ctx,
  * has been set on the parent @ref mongocrypt_t.
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_datakey_init (mongocrypt_ctx_t *ctx);
+bool mongocrypt_ctx_datakey_init(mongocrypt_ctx_t *ctx);
 
 /**
  * Initialize a context for encryption.
@@ -900,11 +806,7 @@ mongocrypt_ctx_datakey_init (mongocrypt_ctx_t *ctx);
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_encrypt_init (mongocrypt_ctx_t *ctx,
-                             const char *db,
-                             int32_t db_len,
-                             mongocrypt_binary_t *cmd);
+bool mongocrypt_ctx_encrypt_init(mongocrypt_ctx_t *ctx, const char *db, int32_t db_len, mongocrypt_binary_t *cmd);
 
 /**
  * Explicit helper method to encrypt a single BSON object. Contexts
@@ -942,9 +844,7 @@ mongocrypt_ctx_encrypt_init (mongocrypt_ctx_t *ctx,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_explicit_encrypt_init (mongocrypt_ctx_t *ctx,
-                                      mongocrypt_binary_t *msg);
+bool mongocrypt_ctx_explicit_encrypt_init(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *msg);
 
 /**
  * Explicit helper method to encrypt a Match Expression or Aggregate Expression.
@@ -991,10 +891,7 @@ mongocrypt_ctx_explicit_encrypt_init (mongocrypt_ctx_t *ctx,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_explicit_encrypt_expression_init (mongocrypt_ctx_t *ctx,
-                                                 mongocrypt_binary_t *msg);
-
+bool mongocrypt_ctx_explicit_encrypt_expression_init(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *msg);
 
 /**
  * Initialize a context for decryption.
@@ -1010,9 +907,7 @@ mongocrypt_ctx_explicit_encrypt_expression_init (mongocrypt_ctx_t *ctx,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_decrypt_init (mongocrypt_ctx_t *ctx, mongocrypt_binary_t *doc);
-
+bool mongocrypt_ctx_decrypt_init(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *doc);
 
 /**
  * Explicit helper method to decrypt a single BSON object.
@@ -1028,10 +923,7 @@ mongocrypt_ctx_decrypt_init (mongocrypt_ctx_t *ctx, mongocrypt_binary_t *doc);
  * immediately after.
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_explicit_decrypt_init (mongocrypt_ctx_t *ctx,
-                                      mongocrypt_binary_t *msg);
-
+bool mongocrypt_ctx_explicit_decrypt_init(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *msg);
 
 /**
  * @brief Initialize a context to rewrap datakeys.
@@ -1046,10 +938,7 @@ mongocrypt_ctx_explicit_decrypt_init (mongocrypt_ctx_t *ctx,
  * Retrieve it with @ref mongocrypt_ctx_status.
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_rewrap_many_datakey_init (mongocrypt_ctx_t *ctx,
-                                         mongocrypt_binary_t *filter);
-
+bool mongocrypt_ctx_rewrap_many_datakey_init(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *filter);
 
 /**
  * Indicates the state of the @ref mongocrypt_ctx_t. Each state requires
@@ -1058,17 +947,16 @@ mongocrypt_ctx_rewrap_many_datakey_init (mongocrypt_ctx_t *ctx,
  * for information on what to do for each state.
  */
 typedef enum {
-   MONGOCRYPT_CTX_ERROR = 0,
-   MONGOCRYPT_CTX_NEED_MONGO_COLLINFO = 1, /* run on main MongoClient */
-   MONGOCRYPT_CTX_NEED_MONGO_MARKINGS = 2, /* run on mongocryptd. */
-   MONGOCRYPT_CTX_NEED_MONGO_KEYS = 3,     /* run on key vault */
-   MONGOCRYPT_CTX_NEED_KMS = 4,
-   MONGOCRYPT_CTX_NEED_KMS_CREDENTIALS = 7, /* fetch/renew KMS credentials */
-   MONGOCRYPT_CTX_READY = 5, /* ready for encryption/decryption */
-   MONGOCRYPT_CTX_DONE = 6,
+    MONGOCRYPT_CTX_ERROR = 0,
+    MONGOCRYPT_CTX_NEED_MONGO_COLLINFO = 1, /* run on main MongoClient */
+    MONGOCRYPT_CTX_NEED_MONGO_MARKINGS = 2, /* run on mongocryptd. */
+    MONGOCRYPT_CTX_NEED_MONGO_KEYS = 3,     /* run on key vault */
+    MONGOCRYPT_CTX_NEED_KMS = 4,
+    MONGOCRYPT_CTX_NEED_KMS_CREDENTIALS = 7, /* fetch/renew KMS credentials */
+    MONGOCRYPT_CTX_READY = 5,                /* ready for encryption/decryption */
+    MONGOCRYPT_CTX_DONE = 6,
 } mongocrypt_ctx_state_t;
 
-
 /**
  * Get the current state of a context.
  *
@@ -1076,9 +964,7 @@ typedef enum {
  * @returns A @ref mongocrypt_ctx_state_t.
  */
 MONGOCRYPT_EXPORT
-mongocrypt_ctx_state_t
-mongocrypt_ctx_state (mongocrypt_ctx_t *ctx);
-
+mongocrypt_ctx_state_t mongocrypt_ctx_state(mongocrypt_ctx_t *ctx);
 
 /**
  * Get BSON necessary to run the mongo operation when mongocrypt_ctx_t
@@ -1101,9 +987,7 @@ mongocrypt_ctx_state (mongocrypt_ctx_t *ctx);
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_mongo_op (mongocrypt_ctx_t *ctx, mongocrypt_binary_t *op_bson);
-
+bool mongocrypt_ctx_mongo_op(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *op_bson);
 
 /**
  * Feed a BSON reply or result when mongocrypt_ctx_t is in
@@ -1128,9 +1012,7 @@ mongocrypt_ctx_mongo_op (mongocrypt_ctx_t *ctx, mongocrypt_binary_t *op_bson);
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_mongo_feed (mongocrypt_ctx_t *ctx, mongocrypt_binary_t *reply);
-
+bool mongocrypt_ctx_mongo_feed(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *reply);
 
 /**
  * Call when done feeding the reply (or replies) back to the context.
@@ -1140,16 +1022,13 @@ mongocrypt_ctx_mongo_feed (mongocrypt_ctx_t *ctx, mongocrypt_binary_t *reply);
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_mongo_done (mongocrypt_ctx_t *ctx);
-
+bool mongocrypt_ctx_mongo_done(mongocrypt_ctx_t *ctx);
 
 /**
  * Manages a single KMS HTTP request/response.
  */
 typedef struct _mongocrypt_kms_ctx_t mongocrypt_kms_ctx_t;
 
-
 /**
  * Get the next KMS handle.
  *
@@ -1164,9 +1043,7 @@ typedef struct _mongocrypt_kms_ctx_t mongocrypt_kms_ctx_t;
  * @returns a new @ref mongocrypt_kms_ctx_t or NULL.
  */
 MONGOCRYPT_EXPORT
-mongocrypt_kms_ctx_t *
-mongocrypt_ctx_next_kms_ctx (mongocrypt_ctx_t *ctx);
-
+mongocrypt_kms_ctx_t *mongocrypt_ctx_next_kms_ctx(mongocrypt_ctx_t *ctx);
 
 /**
  * Get the HTTP request message for a KMS handle.
@@ -1182,10 +1059,7 @@ mongocrypt_ctx_next_kms_ctx (mongocrypt_ctx_t *ctx);
  * Retrieve it with @ref mongocrypt_kms_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_kms_ctx_message (mongocrypt_kms_ctx_t *kms,
-                            mongocrypt_binary_t *msg);
-
+bool mongocrypt_kms_ctx_message(mongocrypt_kms_ctx_t *kms, mongocrypt_binary_t *msg);
 
 /**
  * Get the hostname from which to connect over TLS.
@@ -1202,9 +1076,7 @@ mongocrypt_kms_ctx_message (mongocrypt_kms_ctx_t *kms,
  * Retrieve it with @ref mongocrypt_kms_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_kms_ctx_endpoint (mongocrypt_kms_ctx_t *kms, const char **endpoint);
-
+bool mongocrypt_kms_ctx_endpoint(mongocrypt_kms_ctx_t *kms, const char **endpoint);
 
 /**
  * Indicates how many bytes to feed into @ref mongocrypt_kms_ctx_feed.
@@ -1213,9 +1085,7 @@ mongocrypt_kms_ctx_endpoint (mongocrypt_kms_ctx_t *kms, const char **endpoint);
  * @returns The number of requested bytes.
  */
 MONGOCRYPT_EXPORT
-uint32_t
-mongocrypt_kms_ctx_bytes_needed (mongocrypt_kms_ctx_t *kms);
-
+uint32_t mongocrypt_kms_ctx_bytes_needed(mongocrypt_kms_ctx_t *kms);
 
 /**
  * Feed bytes from the HTTP response.
@@ -1230,9 +1100,7 @@ mongocrypt_kms_ctx_bytes_needed (mongocrypt_kms_ctx_t *kms);
  * Retrieve it with @ref mongocrypt_kms_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_kms_ctx_feed (mongocrypt_kms_ctx_t *kms, mongocrypt_binary_t *bytes);
-
+bool mongocrypt_kms_ctx_feed(mongocrypt_kms_ctx_t *kms, mongocrypt_binary_t *bytes);
 
 /**
  * Get the status associated with a @ref mongocrypt_kms_ctx_t object.
@@ -1243,9 +1111,7 @@ mongocrypt_kms_ctx_feed (mongocrypt_kms_ctx_t *kms, mongocrypt_binary_t *bytes);
  * @returns A boolean indicating success. If false, an error status is set.
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_kms_ctx_status (mongocrypt_kms_ctx_t *kms,
-                           mongocrypt_status_t *status);
+bool mongocrypt_kms_ctx_status(mongocrypt_kms_ctx_t *kms, mongocrypt_status_t *status);
 
 /**
  * Get the KMS provider identifier associated with this KMS request.
@@ -1263,9 +1129,7 @@ mongocrypt_kms_ctx_status (mongocrypt_kms_ctx_t *kms,
  * "kmip".
  */
 MONGOCRYPT_EXPORT
-const char *
-mongocrypt_kms_ctx_get_kms_provider (mongocrypt_kms_ctx_t *kms, uint32_t *len);
-
+const char *mongocrypt_kms_ctx_get_kms_provider(mongocrypt_kms_ctx_t *kms, uint32_t *len);
 
 /**
  * Call when done handling all KMS contexts.
@@ -1276,9 +1140,7 @@ mongocrypt_kms_ctx_get_kms_provider (mongocrypt_kms_ctx_t *kms, uint32_t *len);
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_kms_done (mongocrypt_ctx_t *ctx);
-
+bool mongocrypt_ctx_kms_done(mongocrypt_ctx_t *ctx);
 
 /**
  * Call in response to the MONGOCRYPT_CTX_NEED_KMS_CREDENTIALS state
@@ -1295,9 +1157,7 @@ mongocrypt_ctx_kms_done (mongocrypt_ctx_t *ctx);
  * Retrieve it with @ref mongocrypt_ctx_status.
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_provide_kms_providers (
-   mongocrypt_ctx_t *ctx, mongocrypt_binary_t *kms_providers_definition);
+bool mongocrypt_ctx_provide_kms_providers(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *kms_providers_definition);
 
 /**
  * Perform the final encryption or decryption.
@@ -1336,9 +1196,7 @@ mongocrypt_ctx_provide_kms_providers (
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_finalize (mongocrypt_ctx_t *ctx, mongocrypt_binary_t *out);
-
+bool mongocrypt_ctx_finalize(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *out);
 
 /**
  * Destroy and free all memory associated with a @ref mongocrypt_ctx_t.
@@ -1346,8 +1204,7 @@ mongocrypt_ctx_finalize (mongocrypt_ctx_t *ctx, mongocrypt_binary_t *out);
  * @param[in] ctx A @ref mongocrypt_ctx_t.
  */
 MONGOCRYPT_EXPORT
-void
-mongocrypt_ctx_destroy (mongocrypt_ctx_t *ctx);
+void mongocrypt_ctx_destroy(mongocrypt_ctx_t *ctx);
 
 /**
  * An crypto AES-256-CBC encrypt or decrypt function.
@@ -1366,13 +1223,13 @@ mongocrypt_ctx_destroy (mongocrypt_ctx_t *ctx);
  * @returns A boolean indicating success. If returning false, set @p status
  * with a message indiciating the error using @ref mongocrypt_status_set.
  */
-typedef bool (*mongocrypt_crypto_fn) (void *ctx,
-                                      mongocrypt_binary_t *key,
-                                      mongocrypt_binary_t *iv,
-                                      mongocrypt_binary_t *in,
-                                      mongocrypt_binary_t *out,
-                                      uint32_t *bytes_written,
-                                      mongocrypt_status_t *status);
+typedef bool (*mongocrypt_crypto_fn)(void *ctx,
+                                     mongocrypt_binary_t *key,
+                                     mongocrypt_binary_t *iv,
+                                     mongocrypt_binary_t *in,
+                                     mongocrypt_binary_t *out,
+                                     uint32_t *bytes_written,
+                                     mongocrypt_status_t *status);
 
 /**
  * A crypto signature or HMAC function.
@@ -1391,12 +1248,11 @@ typedef bool (*mongocrypt_crypto_fn) (void *ctx,
  * @returns A boolean indicating success. If returning false, set @p status
  * with a message indiciating the error using @ref mongocrypt_status_set.
  */
-typedef bool (*mongocrypt_hmac_fn) (void *ctx,
-                                    mongocrypt_binary_t *key,
-                                    mongocrypt_binary_t *in,
-                                    mongocrypt_binary_t *out,
-                                    mongocrypt_status_t *status);
-
+typedef bool (*mongocrypt_hmac_fn)(void *ctx,
+                                   mongocrypt_binary_t *key,
+                                   mongocrypt_binary_t *in,
+                                   mongocrypt_binary_t *out,
+                                   mongocrypt_status_t *status);
 
 /**
  * A crypto hash (SHA-256) function.
@@ -1411,10 +1267,10 @@ typedef bool (*mongocrypt_hmac_fn) (void *ctx,
  * @returns A boolean indicating success. If returning false, set @p status
  * with a message indiciating the error using @ref mongocrypt_status_set.
  */
-typedef bool (*mongocrypt_hash_fn) (void *ctx,
-                                    mongocrypt_binary_t *in,
-                                    mongocrypt_binary_t *out,
-                                    mongocrypt_status_t *status);
+typedef bool (*mongocrypt_hash_fn)(void *ctx,
+                                   mongocrypt_binary_t *in,
+                                   mongocrypt_binary_t *out,
+                                   mongocrypt_status_t *status);
 
 /**
  * A crypto secure random function.
@@ -1429,21 +1285,17 @@ typedef bool (*mongocrypt_hash_fn) (void *ctx,
  * @returns A boolean indicating success. If returning false, set @p status
  * with a message indiciating the error using @ref mongocrypt_status_set.
  */
-typedef bool (*mongocrypt_random_fn) (void *ctx,
-                                      mongocrypt_binary_t *out,
-                                      uint32_t count,
-                                      mongocrypt_status_t *status);
+typedef bool (*mongocrypt_random_fn)(void *ctx, mongocrypt_binary_t *out, uint32_t count, mongocrypt_status_t *status);
 
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_setopt_crypto_hooks (mongocrypt_t *crypt,
-                                mongocrypt_crypto_fn aes_256_cbc_encrypt,
-                                mongocrypt_crypto_fn aes_256_cbc_decrypt,
-                                mongocrypt_random_fn random,
-                                mongocrypt_hmac_fn hmac_sha_512,
-                                mongocrypt_hmac_fn hmac_sha_256,
-                                mongocrypt_hash_fn sha_256,
-                                void *ctx);
+bool mongocrypt_setopt_crypto_hooks(mongocrypt_t *crypt,
+                                    mongocrypt_crypto_fn aes_256_cbc_encrypt,
+                                    mongocrypt_crypto_fn aes_256_cbc_decrypt,
+                                    mongocrypt_random_fn random,
+                                    mongocrypt_hmac_fn hmac_sha_512,
+                                    mongocrypt_hmac_fn hmac_sha_256,
+                                    mongocrypt_hash_fn sha_256,
+                                    void *ctx);
 
 /**
  * Set a crypto hook for the AES256-CTR operations.
@@ -1461,11 +1313,10 @@ mongocrypt_setopt_crypto_hooks (mongocrypt_t *crypt,
  *
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_setopt_aes_256_ctr (mongocrypt_t *crypt,
-                               mongocrypt_crypto_fn aes_256_ctr_encrypt,
-                               mongocrypt_crypto_fn aes_256_ctr_decrypt,
-                               void *ctx);
+bool mongocrypt_setopt_aes_256_ctr(mongocrypt_t *crypt,
+                                   mongocrypt_crypto_fn aes_256_ctr_encrypt,
+                                   mongocrypt_crypto_fn aes_256_ctr_decrypt,
+                                   void *ctx);
 
 /**
  * Set an AES256-ECB crypto hook for the AES256-CTR operations. If CTR hook was
@@ -1483,10 +1334,7 @@ mongocrypt_setopt_aes_256_ctr (mongocrypt_t *crypt,
  *
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_setopt_aes_256_ecb (mongocrypt_t *crypt,
-                               mongocrypt_crypto_fn aes_256_ecb_encrypt,
-                               void *ctx);
+bool mongocrypt_setopt_aes_256_ecb(mongocrypt_t *crypt, mongocrypt_crypto_fn aes_256_ecb_encrypt, void *ctx);
 
 /**
  * Set a crypto hook for the RSASSA-PKCS1-v1_5 algorithm with a SHA-256 hash.
@@ -1506,11 +1354,9 @@ mongocrypt_setopt_aes_256_ecb (mongocrypt_t *crypt,
  *
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_setopt_crypto_hook_sign_rsaes_pkcs1_v1_5 (
-   mongocrypt_t *crypt,
-   mongocrypt_hmac_fn sign_rsaes_pkcs1_v1_5,
-   void *sign_ctx);
+bool mongocrypt_setopt_crypto_hook_sign_rsaes_pkcs1_v1_5(mongocrypt_t *crypt,
+                                                         mongocrypt_hmac_fn sign_rsaes_pkcs1_v1_5,
+                                                         void *sign_ctx);
 
 /**
  * @brief Opt-into skipping query analysis.
@@ -1522,8 +1368,7 @@ mongocrypt_setopt_crypto_hook_sign_rsaes_pkcs1_v1_5 (
  * @param[in] crypt The @ref mongocrypt_t object to update
  */
 MONGOCRYPT_EXPORT
-void
-mongocrypt_setopt_bypass_query_analysis (mongocrypt_t *crypt);
+void mongocrypt_setopt_bypass_query_analysis(mongocrypt_t *crypt);
 
 /**
  * Set the contention factor used for explicit encryption.
@@ -1536,9 +1381,7 @@ mongocrypt_setopt_bypass_query_analysis (mongocrypt_t *crypt);
  * Retrieve it with @ref mongocrypt_ctx_status.
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_setopt_contention_factor (mongocrypt_ctx_t *ctx,
-                                         int64_t contention_factor);
+bool mongocrypt_ctx_setopt_contention_factor(mongocrypt_ctx_t *ctx, int64_t contention_factor);
 
 /**
  * Set the index key id to use for explicit Queryable Encryption.
@@ -1556,10 +1399,7 @@ mongocrypt_ctx_setopt_contention_factor (mongocrypt_ctx_t *ctx,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_setopt_index_key_id (mongocrypt_ctx_t *ctx,
-                                    mongocrypt_binary_t *key_id);
-
+bool mongocrypt_ctx_setopt_index_key_id(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *key_id);
 
 /**
  * Set the query type to use for explicit Queryable Encryption.
@@ -1572,10 +1412,7 @@ mongocrypt_ctx_setopt_index_key_id (mongocrypt_ctx_t *ctx,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_setopt_query_type (mongocrypt_ctx_t *ctx,
-                                  const char *query_type,
-                                  int len);
+bool mongocrypt_ctx_setopt_query_type(mongocrypt_ctx_t *ctx, const char *query_type, int len);
 
 /**
  * Set options for explicit encryption with the "rangePreview" algorithm.
@@ -1597,9 +1434,7 @@ mongocrypt_ctx_setopt_query_type (mongocrypt_ctx_t *ctx,
  * Retrieve it with @ref mongocrypt_ctx_status
  */
 MONGOCRYPT_EXPORT
-bool
-mongocrypt_ctx_setopt_algorithm_range (mongocrypt_ctx_t *ctx,
-                                       mongocrypt_binary_t *opts);
+bool mongocrypt_ctx_setopt_algorithm_range(mongocrypt_ctx_t *ctx, mongocrypt_binary_t *opts);
 
 /// String constants for setopt_query_type
 #define MONGOCRYPT_QUERY_TYPE_EQUALITY_STR "equality"
